@@ -8,16 +8,19 @@
 #'
 #'@param R Number of bootstrap samples to draw.
 #'
-#'@param ... All other parameters are passed through to \code{\link{matrixpls}}.
+#'@param ... All other arguments are passed through to \code{\link{matrixpls}}.
 #'
 #'@param signChangeCorrection Sign change correction function.
 #'
+#'@param extraFun A function that takes a \code{matrixpls} object and returns a numeric vector. The
+#'vector is appended to bootstrap replication. Can be used for boostrapping additional
+#'statistics calculated based on the estimation results.
+#'
 #'@param stopOnError A logical indicating whether boostrapping should be continued when error occurs
 #' in a replication.
 #'
 #'@inheritParams boot::boot
-#'@inheritParams simsem::sim
-#'@inheritParams matrixpls.boot
+#'
 #'
 #'@return An object of class \code{\link[boot]{boot}}.
 #'
@@ -25,14 +28,16 @@
 #'\code{\link[boot]{boot}}
 #'
 #'Sign change corrections: \code{\link{signChange.individual}}; \code{\link{signChange.construct}}
+#'
 #'@export
 #'
-
-matrixpls.boot <- function(data, R = 500, ..., 
+#'
+matrixpls.boot <- function(data, ..., R = 500,
                            signChangeCorrection = NULL,
                            parallel = c("no", "multicore", "snow"),
                            ncpus = getOption("boot.ncpus", 1L),
-                           stopOnError = FALSE){
+                           stopOnError = FALSE,
+                           extraFun = NULL){
   
   if(! requireNamespace("boot")) stop("matrixpls.boot requires the boot package")
   
@@ -71,13 +76,29 @@ matrixpls.boot <- function(data, R = 500, ...,
                      arguments <- c(list(S),arguments)
                      
                      if(stopOnError){
-                       do.call(matrixpls, arguments)
+                       boot.rep <- do.call(matrixpls, arguments)
                      }
                      else{
                        tryCatch(
-                         do.call(matrixpls, arguments)
+                         boot.rep <- do.call(matrixpls, arguments)
                        )
                      }
+                     
+                     # Add additional statistics
+                     
+                     if(!is.null(extraFun)){
+                       a <- attributes(boot.rep)
+                       boot.rep <-c(boot.rep,extraFun(boot.rep))
+                       a$names <- names(boot.rep)
+                       attributes(boot.rep) <- a
+                     }
+                     
+                     # If the indices are not sorted, then this is not the original sample
+                     # and we can safely omit all attributes to save memory
+                     
+                     if(is.unsorted(indices)) attributes(boot.rep) <- NULL
+                     
+                     boot.rep
                    },
                    R, parallel = parallel, ncpus = ncpus)
   
@@ -85,59 +106,6 @@ matrixpls.boot <- function(data, R = 500, ...,
   boot.out
 }
 
-#'@title Individual indicator sign change correction for boostrapping
-#'
-#'@description Changes the signs of \code{W} to match \code{Worig}
-#'
-#'@param Worig the original weight matrix
-#'
-#'@param W a weight matrix of a bootstrap sample
-#'
-#'@return A weight matrix with the same dimensions as \code{W} after
-#'
-#'@seealso
-#'\code{\link{matrixpls.boot}}
-#'
-#'@family signChangeCorrection
-#'
-#'@references Tenenhaus, M., Esposito Vinzi, V., Chatelin, Y.-M., & Lauro, C. (2005). PLS Path Modeling.
-#'\emph{Computational Statistics & Data Analysis}, 48(1), 159–205. doi:10.1016/j.csda.2004.03.005
-#'
-#'@export
-#'
-
-signChange.individual <- function(Worig,W){
-  W * sign(Worig) * sign(W)
-}
-
-#'@title Construct level sign change correction for boostrapping
-#'
-#'@description Changes the signs of \code{W} on all rows where the sign of the
-#'sum of the row differs between \code{Worig} and \code{W}
-#'
-#'@param Worig the original weight matrix
-#'
-#'@param W a weight matrix of a bootstrap sample
-#'
-#'@return A weight matrix with the same dimensions as \code{W} after
-#'
-#'@seealso
-#'\code{\link{matrixpls.boot}}
-#'
-#'@family signChangeCorrection
-#'
-#'@references Tenenhaus, M., Esposito Vinzi, V., Chatelin, Y.-M., & Lauro, C. (2005). PLS Path Modeling.
-#'\emph{Computational Statistics & Data Analysis}, 48(1), 159–205. doi:10.1016/j.csda.2004.03.005
-#'
-#'@export
-#'
-signChange.construct <- function(Worig,W){
-  origSums <- apply(Worig,1,sum)
-  curSums <- apply(W,1,sum)
-  signs <- ifelse(abs(origSums-curSums) > abs(origSums+curSums), -1,1)
-  sweep(W,MARGIN=1,signs,`*`)
-}
-
 # These are not in use 
 
 #'#@S3method print matrixplsboot
