@@ -23,7 +23,10 @@
 #'\code{\link[semPLS]{sempls}}
 #'
 #'@export
+#'@example example/fragment-requireSemPLS.R
 #'@example example/matrixpls.sempls-example.R
+#'@example example/fragment-endBlock.R
+
 
 matrixpls.sempls <-
   function(model, data, maxit=20, tol=1e-7, scaled=TRUE, sum1=FALSE, wscheme="centroid", pairwise=FALSE,
@@ -189,7 +192,7 @@ matrixpls.sempls <-
     ifelse(pairwise, use <- "pairwise.complete.obs", use <- "everything")
     
     # Start of matrixpls code
-    result$path_coefficients <- t(attr(matrixpls.res,"beta"))
+    result$path_coefficients <- t(attr(matrixpls.res,"inner"))
     result$cross_loadings <- t(attr(matrixpls.res,"IC"))
     # End of matrixpls code
     
@@ -197,8 +200,9 @@ matrixpls.sempls <-
     result$outer_loadings[Wnew==0] <- 0
     
     # Start of matrixpls code
-    result$total_effects <- cbind(0,t(effects(matrixpls.res)$Total))
-    colnames(result$total_effects) <- rownames(result$total_effects)
+    result$total_effects <- result$path_coefficients
+    endo <- which(apply(matrixpls.model$inner != 0,1,any))
+    result$total_effects[,endo] <- t(effects(matrixpls.res)$Total)
     # End of matrixpls code
     
     result$inner_weights <- innerWeights
@@ -244,8 +248,8 @@ matrixpls.sempls <-
     coefNames <- paste("lam",col(ref)[ref==1],unlist(apply(ref,2,function(x) 1:sum(x))),sep="_")
     
     pathNames <- c(pathNames, paste(rownames(inn)[row(inn)[inn==1]], "->", colnames(inn)[col(inn)[inn==1]]))
-    estimates <- c(estimates, t(attr(matrixpls.res,"beta"))[inn==1])
-    coefNames <- c(coefNames, paste("beta",row(inn)[inn==1],col(inn)[inn==1],sep="_"))
+    estimates <- c(estimates, t(attr(matrixpls.res,"inner"))[inn==1])
+    coefNames <- c(coefNames, paste("inner",row(inn)[inn==1],col(inn)[inn==1],sep="_"))
     
     # Start of matrixpls code
     
